@@ -202,7 +202,7 @@ class Invoice(models.Model):
 
     @property
     def total_with_discount(self):
-        return self.total - self.discounted_total
+        return round(self.total - self.discounted_total, 2)
 
     @property
     def total_qty(self):
