@@ -9,8 +9,10 @@ from product_barcode.filters import BarCodeFilter
 from cap.actions import related_field_change_action
 from cap.decorators import short_description, template_list_item
 from tecdoc.filters import ProductCodeFilter
+from exchange.utils import format_printable_price
 from exchange.actions import update_prices
 from categories.models import Category
+from invoices.conf import IS_PRODUCT_PRICE_SHOWN_IN_DEFAULT_CURRENCY
 
 from products.forms import ProductForm
 from products.models import Product
@@ -67,9 +69,17 @@ class ProductAdmin(LogHistoryAdmin):
         'additional_codes',
     )
 
-    @short_description(_('Price, UAH'))
+    @short_description(
+        _('Price, UAH')
+        if IS_PRODUCT_PRICE_SHOWN_IN_DEFAULT_CURRENCY else
+        _('Price')
+    )
     def printable_price(self, item):
-        return item.price
+        return (
+            item.price
+            if IS_PRODUCT_PRICE_SHOWN_IN_DEFAULT_CURRENCY else
+            format_printable_price(item.price_retail, item.initial_currency)
+        )
 
     @template_list_item(
         'invoice_products/admin/list_item_actions.html', _('Actions'))
